@@ -16,14 +16,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <packagekit-glib/packagekit.h>
+#include <packagekit-glib2/packagekit.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -52,6 +52,10 @@ static const PkEnumMatch enum_info_icon_name[] = {
 	{PK_INFO_ENUM_COLLECTION_INSTALLED,	"pk-collection-installed"},
 	{PK_INFO_ENUM_COLLECTION_AVAILABLE,	"pk-collection-available"},
 	{PK_INFO_ENUM_FINISHED,			"dialog-information"},
+	{PK_INFO_ENUM_REINSTALLING,		"dialog-information"},
+	{PK_INFO_ENUM_DOWNGRADING,		"pk-package-update"},
+	{PK_INFO_ENUM_PREPARING,		"dialog-information"},
+	{PK_INFO_ENUM_DECOMPRESSING,		"dialog-information"},
 	{0, NULL}
 };
 
@@ -92,6 +96,7 @@ static const PkEnumMatch enum_status_icon_name[] = {
 	{PK_STATUS_ENUM_SCAN_PROCESS_LIST,	"pk-package-info"},
 	{PK_STATUS_ENUM_CHECK_EXECUTABLE_FILES,	"pk-package-info"},
 	{PK_STATUS_ENUM_CHECK_LIBRARIES,	"pk-package-info"},
+	{PK_STATUS_ENUM_COPY_FILES,		"pk-package-info"},
 	{0, NULL}
 };
 
@@ -132,6 +137,7 @@ static const PkEnumMatch enum_status_animation[] = {
 	{PK_STATUS_ENUM_SCAN_PROCESS_LIST,	"pk-package-info"},
 	{PK_STATUS_ENUM_CHECK_EXECUTABLE_FILES,	"pk-package-info"},
 	{PK_STATUS_ENUM_CHECK_LIBRARIES,	"pk-package-info"},
+	{PK_STATUS_ENUM_COPY_FILES,		"pk-package-info"},
 	{0, NULL}
 };
 
@@ -167,6 +173,10 @@ static const PkEnumMatch enum_role_icon_name[] = {
 	{PK_ROLE_ENUM_UPDATE_PACKAGES,		"pk-package-update"},
 	{PK_ROLE_ENUM_UPDATE_SYSTEM,		"system-software-update"},
 	{PK_ROLE_ENUM_WHAT_PROVIDES,		"pk-package-search"},
+	{PK_ROLE_ENUM_SIMULATE_INSTALL_FILES,	"pk-package-add"},
+	{PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES, "pk-package-add"},
+	{PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES,	"pk-package-delete"},
+	{PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES,	"pk-package-update"},
 	{0, NULL}
 };
 
@@ -246,6 +256,9 @@ static const PkEnumMatch enum_message_icon_name[] = {
 	{PK_MESSAGE_ENUM_CONFIG_FILES_CHANGED,	"dialog-information"},
 	{PK_MESSAGE_ENUM_PACKAGE_ALREADY_INSTALLED,	"dialog-information"},
 	{PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED,	"dialog-information"},
+	{PK_MESSAGE_ENUM_REPO_METADATA_DOWNLOAD_FAILED,	"dialog-warning"},
+	{PK_MESSAGE_ENUM_REPO_FOR_DEVELOPERS_ONLY,	"dialog-warning"},
+	{PK_MESSAGE_ENUM_OTHER_UPDATES_HELD_BACK,	"dialog-information"},
 	{0, NULL}
 };
 
@@ -319,10 +332,13 @@ gpk_media_type_enum_to_localised_text (PkMediaTypeEnum type)
  * gpk_error_enum_to_localised_text:
  **/
 const gchar *
-gpk_error_enum_to_localised_text (PkErrorCodeEnum code)
+gpk_error_enum_to_localised_text (PkErrorEnum code)
 {
 	const gchar *text = NULL;
 	switch (code) {
+	case PK_ERROR_ENUM_UNKNOWN:
+		text = _("Failed with unknown error code");
+		break;
 	case PK_ERROR_ENUM_NO_NETWORK:
 		text = _("No network connection available");
 		break;
@@ -485,6 +501,33 @@ gpk_error_enum_to_localised_text (PkErrorCodeEnum code)
 	case PK_ERROR_ENUM_CANNOT_DISABLE_REPOSITORY:
 		text = _("Cannot disable source");
 		break;
+	case PK_ERROR_ENUM_RESTRICTED_DOWNLOAD:
+		text = _("The download failed");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_CONFIGURE:
+		text = _("Package failed to configure");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_BUILD:
+		text = _("Package failed to build");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_INSTALL:
+		text = _("Package failed to install");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_REMOVE:
+		text = _("Package failed to be removed");
+		break;
+	case PK_ERROR_ENUM_UPDATE_FAILED_DUE_TO_RUNNING_PROCESS:
+		text = _("Update failed due to running process");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_DATABASE_CHANGED:
+		text = _("The package database was changed");
+		break;
+	case PK_ERROR_ENUM_PROVIDE_TYPE_NOT_SUPPORTED:
+		text = _("Virtual provide type is not supported");
+		break;
+	case PK_ERROR_ENUM_INSTALL_ROOT_INVALID:
+		text = _("Install root is invalid");
+		break;
 	default:
 		egg_warning ("Unknown error");
 	}
@@ -495,10 +538,13 @@ gpk_error_enum_to_localised_text (PkErrorCodeEnum code)
  * gpk_error_enum_to_localised_message:
  **/
 const gchar *
-gpk_error_enum_to_localised_message (PkErrorCodeEnum code)
+gpk_error_enum_to_localised_message (PkErrorEnum code)
 {
 	const gchar *text = NULL;
 	switch (code) {
+	case PK_ERROR_ENUM_UNKNOWN:
+		text = _("Failed with unknown error code.");
+		break;
 	case PK_ERROR_ENUM_NO_NETWORK:
 		text = _("There is no network connection available.\n"
 			 "Please check your connection settings and try again.");
@@ -694,6 +740,39 @@ gpk_error_enum_to_localised_message (PkErrorCodeEnum code)
 	case PK_ERROR_ENUM_CANNOT_DISABLE_REPOSITORY:
 		text = _("The specified software source could not be disabled.");
 		break;
+	case PK_ERROR_ENUM_RESTRICTED_DOWNLOAD:
+		text = _("The download could not be done automatically and should be done manually.\n"
+			 "More information is available in the detailed report.");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_CONFIGURE:
+		text = _("One of the selected packages failed to configure correctly.\n"
+			 "More information is available in the detailed report.");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_BUILD:
+		text = _("One of the selected packages failed to build correctly.\n"
+			 "More information is available in the detailed report.");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_INSTALL:
+		text = _("One of the selected packages failed to install correctly.\n"
+			 "More information is available in the detailed report.");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_REMOVE:
+		text = _("One of the selected packages failed to be removed correctly.\n"
+			 "More information is available in the detailed report.");
+		break;
+	case PK_ERROR_ENUM_UPDATE_FAILED_DUE_TO_RUNNING_PROCESS:
+		text = _("A program is running that has to be closed before the update can proceed.\n"
+			 "More information is available in the detailed report.");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_DATABASE_CHANGED:
+		text = _("The package database was changed while the request was running.");
+		break;
+	case PK_ERROR_ENUM_PROVIDE_TYPE_NOT_SUPPORTED:
+		text = _("The virtual provide type is not supported by this system.");
+		break;
+	case PK_ERROR_ENUM_INSTALL_ROOT_INVALID:
+		text = _("The install root is invalid. Please contact your administrator.");
+		break;
 	default:
 		egg_warning ("Unknown error, please report a bug at " GPK_BUGZILLA_URL ".\n"
 			    "More information is available in the detailed report.");
@@ -838,6 +917,15 @@ gpk_message_enum_to_localised_text (PkMessageEnum message)
 	case PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED:
 		text = _("Automatic cleanup is being ignored");
 		break;
+	case PK_MESSAGE_ENUM_REPO_METADATA_DOWNLOAD_FAILED:
+		text = _("Software source download failed");
+		break;
+	case PK_MESSAGE_ENUM_REPO_FOR_DEVELOPERS_ONLY:
+		text = _("This software source is for developers only");
+		break;
+	case PK_MESSAGE_ENUM_OTHER_UPDATES_HELD_BACK:
+		text = _("Other updates have been held back");
+		break;
 	default:
 		egg_warning ("message unrecognised: %i", message);
 	}
@@ -853,131 +941,131 @@ gpk_status_enum_to_localised_text (PkStatusEnum status)
 	const gchar *text = NULL;
 	switch (status) {
 	case PK_STATUS_ENUM_UNKNOWN:
-		/* TRANSLATORS: This is when the status is not known */
+		/* TRANSLATORS: This is when the transaction status is not known */
 		text = _("Unknown state");
 		break;
 	case PK_STATUS_ENUM_SETUP:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, the daemon is in the process of starting */
 		text = _("Starting");
 		break;
 	case PK_STATUS_ENUM_WAIT:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, the transaction is waiting for another to complete */
 		text = _("Waiting in queue");
 		break;
 	case PK_STATUS_ENUM_RUNNING:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, just started */
 		text = _("Running");
 		break;
 	case PK_STATUS_ENUM_QUERY:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, is querying data */
 		text = _("Querying");
 		break;
 	case PK_STATUS_ENUM_INFO:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, getting data from a server */
 		text = _("Getting information");
 		break;
 	case PK_STATUS_ENUM_REMOVE:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, removing packages */
 		text = _("Removing packages");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, downloading package files */
 		text = _("Downloading packages");
 		break;
 	case PK_STATUS_ENUM_INSTALL:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, installing packages */
 		text = _("Installing packages");
 		break;
 	case PK_STATUS_ENUM_REFRESH_CACHE:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, refreshing internal lists */
 		text = _("Refreshing software list");
 		break;
 	case PK_STATUS_ENUM_UPDATE:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, installing updates */
 		text = _("Installing updates");
 		break;
 	case PK_STATUS_ENUM_CLEANUP:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, removing old packages, and cleaning config files */
 		text = _("Cleaning up packages");
 		break;
 	case PK_STATUS_ENUM_OBSOLETE:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, obsoleting old packages */
 		text = _("Obsoleting packages");
 		break;
 	case PK_STATUS_ENUM_DEP_RESOLVE:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, checking the transaction before we do it */
 		text = _("Resolving dependencies");
 		break;
 	case PK_STATUS_ENUM_SIG_CHECK:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, checking if we have all the security keys for the operation */
 		text = _("Checking signatures");
 		break;
 	case PK_STATUS_ENUM_ROLLBACK:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, when we return to a previous system state */
 		text = _("Rolling back");
 		break;
 	case PK_STATUS_ENUM_TEST_COMMIT:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, when we're doing a test transaction */
 		text = _("Testing changes");
 		break;
 	case PK_STATUS_ENUM_COMMIT:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, when we're writing to the system package database */
 		text = _("Committing changes");
 		break;
 	case PK_STATUS_ENUM_REQUEST:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, requesting data from a server */
 		text = _("Requesting data");
 		break;
 	case PK_STATUS_ENUM_FINISHED:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, all done! */
 		text = _("Finished");
 		break;
 	case PK_STATUS_ENUM_CANCEL:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, in the process of cancelling */
 		text = _("Cancelling");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD_REPOSITORY:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, downloading metadata */
 		text = _("Downloading repository information");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD_PACKAGELIST:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, downloading metadata */
 		text = _("Downloading list of packages");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD_FILELIST:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, downloading metadata */
 		text = _("Downloading file lists");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD_CHANGELOG:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, downloading metadata */
 		text = _("Downloading lists of changes");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD_GROUP:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, downloading metadata */
 		text = _("Downloading groups");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD_UPDATEINFO:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, downloading metadata */
 		text = _("Downloading update information");
 		break;
 	case PK_STATUS_ENUM_REPACKAGING:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, repackaging delta files */
 		text = _("Repackaging files");
 		break;
 	case PK_STATUS_ENUM_LOADING_CACHE:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, loading databases */
 		text = _("Loading cache");
 		break;
 	case PK_STATUS_ENUM_SCAN_APPLICATIONS:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, scanning for running processes */
 		text = _("Scanning installed applications");
 		break;
 	case PK_STATUS_ENUM_GENERATE_PACKAGE_LIST:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, generating a list of packages installed on the system */
 		text = _("Generating package lists");
 		break;
 	case PK_STATUS_ENUM_WAITING_FOR_LOCK:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, when we're waiting for the native tools to exit */
 		text = _("Waiting for package manager lock");
 		break;
 	case PK_STATUS_ENUM_WAITING_FOR_AUTH:
@@ -996,6 +1084,10 @@ gpk_status_enum_to_localised_text (PkStatusEnum status)
 		/* TRANSLATORS: we are checking for libraries in use */
 		text = _("Checking for libraries currently in use");
 		break;
+	case PK_STATUS_ENUM_COPY_FILES:
+		/* TRANSLATORS: we are copying package files to prepare to install */
+		text = _("Copying files");
+		break;
 	default:
 		egg_warning ("status unrecognised: %s", pk_status_enum_to_text (status));
 	}
@@ -1128,6 +1220,18 @@ gpk_info_enum_to_localised_present (PkInfoEnum info)
 		/* TRANSLATORS: The action of the package, in present tense */
 		text = _("Obsoleting");
 		break;
+	case PK_INFO_ENUM_REINSTALLING:
+		/* TRANSLATORS: The action of the package, in present tense */
+		text = _("Reinstalling");
+		break;
+	case PK_INFO_ENUM_PREPARING:
+		/* TRANSLATORS: The action of the package, in present tense */
+		text = _("Preparing");
+		break;
+	case PK_INFO_ENUM_DECOMPRESSING:
+		/* TRANSLATORS: The action of the package, in present tense */
+		text = _("Decompressing");
+		break;
 	default:
 		egg_warning ("info unrecognised: %s", pk_info_enum_to_text (info));
 	}
@@ -1166,6 +1270,18 @@ gpk_info_enum_to_localised_past (PkInfoEnum info)
 		/* TRANSLATORS: The action of the package, in past tense */
 		text = _("Obsoleted");
 		break;
+	case PK_INFO_ENUM_REINSTALLING:
+		/* TRANSLATORS: The action of the package, in past tense */
+		text = _("Reinstalled");
+		break;
+	case PK_INFO_ENUM_PREPARING:
+		/* TRANSLATORS: The action of the package, in past tense */
+		text = _("Prepared");
+		break;
+	case PK_INFO_ENUM_DECOMPRESSING:
+		/* TRANSLATORS: The action of the package, in past tense */
+		text = _("Decompressed");
+		break;
 	default:
 		egg_warning ("info unrecognised: %s", pk_info_enum_to_text (info));
 	}
@@ -1304,6 +1420,22 @@ gpk_role_enum_to_localised_present (PkRoleEnum role)
 		/* TRANSLATORS: The role of the transaction, in present tense */
 		text = _("Getting old transactions");
 		break;
+	case PK_ROLE_ENUM_SIMULATE_INSTALL_FILES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = _("Simulating the install of files");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = _("Simulating the install");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = _("Simulating the remove");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = _("Simulating the update");
+		break;
 	default:
 		egg_warning ("role unrecognised: %s", pk_role_enum_to_text (role));
 	}
@@ -1444,6 +1576,22 @@ gpk_role_enum_to_localised_past (PkRoleEnum role)
 		/* TRANSLATORS: The role of the transaction, in past tense */
 		text = _("Got old transactions");
 		break;
+	case PK_ROLE_ENUM_SIMULATE_INSTALL_FILES:
+		/* TRANSLATORS: The role of the transaction, in past tense */
+		text = _("Simulated the install of files");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in past tense */
+		text = _("Simulated the install");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in past tense */
+		text = _("Simulated the remove");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in past tense */
+		text = _("Simulated the update");
+		break;
 	default:
 		egg_warning ("role unrecognised: %s", pk_role_enum_to_text (role));
 	}
@@ -1682,8 +1830,8 @@ gpk_message_enum_to_icon_name (PkMessageEnum message)
 const gchar *
 gpk_info_status_enum_to_text (GpkInfoStatusEnum info)
 {
-	if (info > PK_INFO_ENUM_UNKNOWN)
-		return gpk_info_enum_to_localised_past (info - PK_INFO_ENUM_UNKNOWN);
+	if (info >= PK_INFO_ENUM_LAST)
+		return gpk_info_enum_to_localised_past (info - PK_INFO_ENUM_LAST);
 	return gpk_info_enum_to_localised_present (info);
 }
 
@@ -1701,8 +1849,8 @@ gpk_info_status_enum_to_icon_name (GpkInfoStatusEnum info)
 		return "pk-package-installed";
 
 	/* use normal icon as a fallback */
-	if (info > PK_INFO_ENUM_UNKNOWN)
-		return gpk_info_enum_to_icon_name (info - PK_INFO_ENUM_UNKNOWN);
+	if (info >= PK_INFO_ENUM_LAST)
+		return gpk_info_enum_to_icon_name (info - PK_INFO_ENUM_LAST);
 
 	/* regular PkInfoEnum */
 	return gpk_info_enum_to_icon_name (info);
@@ -1728,7 +1876,7 @@ gpk_enum_test (gpointer data)
 	 ****************     localised enums          **************
 	 ************************************************************/
 	egg_test_title (test, "check we convert all the localised past role enums");
-	for (i=0; i<PK_ROLE_ENUM_UNKNOWN; i++) {
+	for (i=0; i<PK_ROLE_ENUM_LAST; i++) {
 		string = gpk_role_enum_to_localised_past (i);
 		if (string == NULL) {
 			egg_test_failed (test, "failed to get %i", i);
@@ -1739,7 +1887,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the localised present role enums");
-	for (i=0; i<PK_ROLE_ENUM_UNKNOWN; i++) {
+	for (i=0; i<PK_ROLE_ENUM_LAST; i++) {
 		string = gpk_role_enum_to_localised_present (i);
 		if (string == NULL) {
 			egg_test_failed (test, "failed to get %i", i);
@@ -1750,7 +1898,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the role icon name enums");
-	for (i=0; i<PK_ROLE_ENUM_UNKNOWN; i++) {
+	for (i=PK_ROLE_ENUM_UNKNOWN+1; i<PK_ROLE_ENUM_LAST; i++) {
 		string = gpk_role_enum_to_icon_name (i);
 		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_role_enum_to_text (i));
@@ -1761,7 +1909,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the status animation enums");
-	for (i=0; i<PK_ROLE_ENUM_UNKNOWN; i++) {
+	for (i=PK_ROLE_ENUM_UNKNOWN+1; i<PK_ROLE_ENUM_LAST; i++) {
 		string = gpk_status_enum_to_animation (i);
 		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_role_enum_to_text (i));
@@ -1772,7 +1920,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the info icon names enums");
-	for (i=0; i<PK_INFO_ENUM_UNKNOWN; i++) {
+	for (i=PK_INFO_ENUM_UNKNOWN+1; i<PK_INFO_ENUM_LAST; i++) {
 		string = gpk_info_enum_to_icon_name (i);
 		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_info_enum_to_text (i));
@@ -1783,7 +1931,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the localised status enums");
-	for (i=0; i<PK_STATUS_ENUM_UNKNOWN; i++) {
+	for (i=0; i<PK_STATUS_ENUM_LAST; i++) {
 		string = gpk_status_enum_to_localised_text (i);
 		if (string == NULL) {
 			egg_test_failed (test, "failed to get %i", i);
@@ -1794,7 +1942,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the status icon names enums");
-	for (i=0; i<PK_STATUS_ENUM_UNKNOWN; i++) {
+	for (i=PK_STATUS_ENUM_UNKNOWN+1; i<PK_STATUS_ENUM_LAST; i++) {
 		string = gpk_status_enum_to_icon_name (i);
 		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_status_enum_to_text (i));
@@ -1805,7 +1953,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the restart icon names enums");
-	for (i=0; i<PK_RESTART_ENUM_UNKNOWN; i++) {
+	for (i=PK_RESTART_ENUM_UNKNOWN+1; i<PK_RESTART_ENUM_LAST; i++) {
 		string = gpk_restart_enum_to_icon_name (i);
 		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_restart_enum_to_text (i));
@@ -1816,7 +1964,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the localised error enums");
-	for (i=0; i<PK_ERROR_ENUM_UNKNOWN; i++) {
+	for (i=0; i<PK_ERROR_ENUM_LAST; i++) {
 		string = gpk_error_enum_to_localised_text (i);
 		if (string == NULL) {
 			egg_test_failed (test, "failed to get %s", pk_error_enum_to_text(i));
@@ -1827,7 +1975,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the localised error messages");
-	for (i=0; i<PK_ERROR_ENUM_UNKNOWN; i++) {
+	for (i=0; i<PK_ERROR_ENUM_LAST; i++) {
 		string = gpk_error_enum_to_localised_message (i);
 		if (string == NULL) {
 			egg_test_failed (test, "failed to get %s", pk_error_enum_to_text(i));
@@ -1838,7 +1986,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the localised restart enums");
-	for (i=0; i<PK_RESTART_ENUM_UNKNOWN; i++) {
+	for (i=PK_RESTART_ENUM_UNKNOWN+1; i<PK_RESTART_ENUM_LAST; i++) {
 		string = gpk_restart_enum_to_localised_text (i);
 		if (string == NULL) {
 			egg_test_failed (test, "failed to get %i", i);
@@ -1849,7 +1997,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the message icon name enums");
-	for (i=0; i<PK_MESSAGE_ENUM_UNKNOWN; i++) {
+	for (i=PK_MESSAGE_ENUM_UNKNOWN+1; i<PK_MESSAGE_ENUM_LAST; i++) {
 		string = gpk_message_enum_to_icon_name (i);
 		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_message_enum_to_text (i));
@@ -1860,7 +2008,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the localised message enums");
-	for (i=0; i<PK_MESSAGE_ENUM_UNKNOWN; i++) {
+	for (i=PK_MESSAGE_ENUM_UNKNOWN+1; i<PK_MESSAGE_ENUM_LAST; i++) {
 		string = gpk_message_enum_to_localised_text (i);
 		if (string == NULL) {
 			egg_test_failed (test, "failed to get %i", i);
@@ -1871,7 +2019,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the localised restart future enums");
-	for (i=0; i<PK_RESTART_ENUM_UNKNOWN; i++) {
+	for (i=PK_RESTART_ENUM_UNKNOWN+1; i<PK_RESTART_ENUM_LAST; i++) {
 		string = gpk_restart_enum_to_localised_text_future (i);
 		if (string == NULL) {
 			egg_test_failed (test, "failed to get %i", i);
@@ -1882,7 +2030,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the localised group enums");
-	for (i=0; i<PK_GROUP_ENUM_UNKNOWN; i++) {
+	for (i=0; i<PK_GROUP_ENUM_LAST; i++) {
 		string = gpk_group_enum_to_localised_text (i);
 		if (string == NULL) {
 			egg_test_failed (test, "failed to get %i", i);
@@ -1893,7 +2041,7 @@ gpk_enum_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check we convert all the group icon name enums");
-	for (i=0; i<PK_GROUP_ENUM_UNKNOWN; i++) {
+	for (i=PK_GROUP_ENUM_UNKNOWN+1; i<PK_GROUP_ENUM_LAST; i++) {
 		string = gpk_group_enum_to_icon_name (i);
 		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_group_enum_to_text (i));
