@@ -16,22 +16,17 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
 
-#include <glib.h>
 #include <glib/gi18n.h>
 #include <locale.h>
 
 #include <gtk/gtk.h>
-#include <math.h>
-#include <string.h>
 #include <sys/utsname.h>
-#include <dbus/dbus-glib.h>
-#include <gconf/gconf-client.h>
-#include <packagekit-glib/packagekit.h>
+#include <packagekit-glib2/packagekit.h>
 #include <unique/unique.h>
 
 #include "egg-debug.h"
@@ -50,6 +45,7 @@ typedef enum {
 
 static GtkBuilder *builder = NULL;
 static PkClient *client = NULL;
+static PkControl *control = NULL;
 static GpkActionEnum action = GPK_ACTION_ENUM_UPDATES;
 static guint pulse_id = 0;
 
@@ -81,14 +77,17 @@ gpk_pack_get_default_filename (const gchar *directory)
 	gchar *nodename = NULL;
 	const gchar *package;
 
-	distro_id = pk_get_distro_id ();
+	/* get the distro-id from the daemon */
+	g_object_get (control,
+		      "distro-id", &distro_id,
+		      NULL);
 	if (action == GPK_ACTION_ENUM_PACKAGE) {
 		entry = GTK_ENTRY (gtk_builder_get_object (builder, "entry_package"));
 		package = gtk_entry_get_text (entry);
 		filename = g_strdup_printf ("%s/%s-%s.servicepack", directory, package, distro_id);
 	} else if (action == GPK_ACTION_ENUM_COPY) {
 		nodename = pk_get_node_name ();
-		filename = g_strdup_printf ("%s/%s.package-list", directory, nodename);
+		filename = g_strdup_printf ("%s/%s.package-array", directory, nodename);
 	} else if (action == GPK_ACTION_ENUM_UPDATES) {
 		iso_time = pk_iso8601_present ();
 		/* don't include the time, just use the date prefix */
@@ -134,22 +133,6 @@ gpk_pack_widgets_activate (gboolean enable)
 	gtk_widget_set_sensitive (widget, enable);
 }
 
-/**
- * gpk_pack_package_cb:
- **/
-static void
-gpk_pack_package_cb (PkServicePack *pack, const PkPackageObj *obj, gpointer data)
-{
-	GtkProgressBar *progress_bar;
-	gchar *text;
-
-	progress_bar = GTK_PROGRESS_BAR (gtk_builder_get_object (builder, "progressbar_percentage"));
-	/* TRANSLATORS: This is the package name that is being downloaded */
-	text = g_strdup_printf ("%s: %s-%s.%s", _("Downloading"), obj->id->name, obj->id->version, obj->id->arch);
-	gtk_progress_bar_set_text (progress_bar, text);
-	g_free (text);
-}
-
 /**
  * gpk_pack_percentage_pulse_cb:
  **/
@@ -173,8 +156,12 @@ gpk_pack_set_percentage (guint percentage)
 	/* no info */
 	if (percentage == 101) {
 		/* set pulsing */
-		if (pulse_id == 0)
+		if (pulse_id == 0) {
 			pulse_id = g_timeout_add (100, gpk_pack_percentage_pulse_cb, NULL);
+#if GLIB_CHECK_VERSION(2,25,8)
+			g_source_set_name_by_id (pulse_id, "[GpkServicePack] pulse");
+#endif
+		}
 		return;
 	}
 
@@ -188,75 +175,58 @@ gpk_pack_set_percentage (guint percentage)
 	gtk_progress_bar_set_fraction (progress_bar, percentage / 100.0f);
 }
 
-/**
- * gpk_pack_percentage_cb:
- **/
-static void
-gpk_pack_percentage_cb (PkServicePack *pack, guint percentage, gpointer data)
-{
-	gpk_pack_set_percentage (percentage);
-}
-
-/**
- * gpk_pack_progress_changed_cb:
- **/
-static void
-gpk_pack_progress_changed_cb (PkClient *_client, guint percentage, guint subpercentage,
-			      guint elapsed, guint remaining, gpointer data)
-{
-	gpk_pack_set_percentage (percentage);
-}
-
 /**
  * gpk_pack_resolve_package_id:
  **/
 static gchar *
 gpk_pack_resolve_package_id (const gchar *package)
 {
-	PkPackageList *list = NULL;
+	GPtrArray *array = NULL;
 	gchar *package_id = NULL;
 	gchar **packages = NULL;
 	GError *error = NULL;
-	const PkPackageObj *obj;
-	gboolean ret = FALSE;
-	guint len;
+	PkPackage *item;
+	PkResults *results;
+	PkError *error_code = NULL;
 
-	/* reset client */
-	ret = pk_client_reset (client, &error);
-	if (!ret) {
-		egg_warning ("could not reset client: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	/* get package list */
+	/* get package array */
 	packages = g_strsplit (package, ";", 0);
-	ret = pk_client_resolve (client, pk_bitfield_value (PK_FILTER_ENUM_NEWEST), packages, &error);
-	if (!ret) {
+	results = pk_client_resolve (client, pk_bitfield_value (PK_FILTER_ENUM_NEWEST), packages, NULL, NULL, NULL, &error);
+	if (results == NULL) {
 		egg_warning ("failed to resolve: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
 
+	/* check error code */
+	error_code = pk_results_get_error_code (results);
+	if (error_code != NULL) {
+		egg_warning ("failed to resolve: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
+		goto out;
+	}
+
 	/* get the deps */
-	list = pk_client_get_package_list (client);
-	len = pk_package_list_get_size (list);
+	array = pk_results_get_package_array (results);
 
 	/* no matches */
-	if (len == 0)
+	if (array->len == 0)
 		goto out;
 
 	/* display warning if not exactly one match */
-	if (len > 1)
+	if (array->len > 1)
 		egg_warning ("More than one possible package for '%s' found!", package);
 
 	/* convert to a text package id */
-	obj = pk_package_list_get_obj (list, 0);
-	package_id = pk_package_id_to_string (obj->id);
+	item = g_ptr_array_index (array, 0);
+	package_id = g_strdup (pk_package_get_id (item));
 
 out:
-	if (list != NULL)
-		g_object_unref (list);
+	if (error_code != NULL)
+		g_object_unref (error_code);
+	if (array != NULL)
+		g_ptr_array_unref (array);
+	if (results != NULL)
+		g_object_unref (results);
 	g_strfreev (packages);
 	return package_id;
 }
@@ -274,7 +244,7 @@ gpk_pack_resolve_package_ids (gchar **package, GError **error)
 	gchar *package_id;
 
 	length = g_strv_length (package);
-	array = g_ptr_array_new ();
+	array = g_ptr_array_new_with_free_func (g_free);
 
 	/* for each package, resolve to a package_id */
 	for (i=0; i<length; i++) {
@@ -287,7 +257,7 @@ gpk_pack_resolve_package_ids (gchar **package, GError **error)
 		package_id = gpk_pack_resolve_package_id (package[i]);
 		if (package_id == NULL) {
 			/* TRANSLATORS: cannot resolve name to package name */
-			*error = g_error_new (1, 0, _("Could not find any packages named '%s'"), package[i]);
+			g_set_error (error, 1, 0, _("Could not find any packages named '%s'"), package[i]);
 			ret = FALSE;
 			break;
 		}
@@ -299,7 +269,7 @@ gpk_pack_resolve_package_ids (gchar **package, GError **error)
 	/* no packages */
 	if (array->len == 0) {
 		/* TRANSLATORS: cannot find any valid package names */
-		*error = g_error_new (1, 0, _("Could not find any valid package names"));
+		g_set_error_literal (error, 1, 0, _("Could not find any valid package names"));
 		goto out;
 	}
 
@@ -309,11 +279,43 @@ gpk_pack_resolve_package_ids (gchar **package, GError **error)
 
 out:
 	/* free temp array */
-	g_ptr_array_foreach (array, (GFunc) g_free, NULL);
-	g_ptr_array_free (array, TRUE);
+	g_ptr_array_unref (array);
 	return package_ids;
 }
 
+/**
+ * gpk_pack_package_array_to_string:
+ **/
+static gchar *
+gpk_pack_package_array_to_string (GPtrArray *array)
+{
+	guint i;
+	PkPackage *item;
+	GString *string;
+	PkInfoEnum info;
+	gchar *package_id = NULL;
+	gchar *summary = NULL;
+
+	string = g_string_new ("");
+	for (i=0; i<array->len; i++) {
+		item = g_ptr_array_index (array, i);
+		g_object_get (item,
+			      "info", &info,
+			      "package-id", &package_id,
+			      "summary", &summary,
+			      NULL);
+		g_string_append_printf (string, "%s\t%s\t%s\n",
+					pk_info_enum_to_text (info), package_id, summary);
+		g_free (package_id);
+		g_free (summary);
+	}
+
+	/* remove trailing newline */
+	if (string->len != 0)
+		g_string_set_size (string, string->len-1);
+	return g_string_free (string, FALSE);
+}
+
 /**
  * gpk_pack_copy_package_lists:
  **/
@@ -321,43 +323,160 @@ static gboolean
 gpk_pack_copy_package_lists (const gchar *filename, GError **error)
 {
 	gboolean ret = FALSE;
-	PkPackageList *list = NULL;
+	GPtrArray *array = NULL;
 	GError *error_local = NULL;
+	PkResults *results;
+	gchar *data = NULL;
+	PkError *error_code = NULL;
 
-	/* reset client */
-	ret = pk_client_reset (client, &error_local);
-	if (!ret) {
-		/* TRANSLATORS: internal error */
-		*error = g_error_new (1, 0, _("Could not reset client: %s"), error_local->message);
+	/* get package array */
+	results = pk_client_get_packages (client, pk_bitfield_value (PK_FILTER_ENUM_INSTALLED), NULL, NULL, NULL, &error_local);
+	if (results == NULL) {
+		/* TRANSLATORS: cannot get package array */
+		g_set_error (error, 1, 0, _("Could not get array of installed packages: %s"), error_local->message);
 		g_error_free (error_local);
 		goto out;
 	}
 
-	/* get package list */
-	ret = pk_client_get_packages (client, pk_bitfield_value (PK_FILTER_ENUM_INSTALLED), &error_local);
-	if (!ret) {
-		/* TRANSLATORS: cannot get package list */
-		*error = g_error_new (1, 0, _("Could not get list of installed packages: %s"), error_local->message);
-		g_error_free (error_local);
+	/* check error code */
+	error_code = pk_results_get_error_code (results);
+	if (error_code != NULL) {
+		egg_warning ("failed to get packages: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
 		goto out;
 	}
 
 	/* get the deps */
-	list = pk_client_get_package_list (client);
+	array = pk_results_get_package_array (results);
 
-	/* write new file : FIXME: return a GError */
-	ret = pk_obj_list_to_file (PK_OBJ_LIST(list), filename);
+	/* convert to a file */
+	data = gpk_pack_package_array_to_string (array);
+	ret = g_file_set_contents (PK_SYSTEM_PACKAGE_LIST_FILENAME, data, -1, &error_local);
 	if (!ret) {
-		/* TRANSLATORS: we could not write to the destination directory for some reason */
-		*error = g_error_new (1, 0, _("Could not write package list"));
+		g_set_error (error, 1, 0, _("Could not save to file: %s"), error_local->message);
+		g_error_free (error_local);
 		goto out;
 	}
 out:
-	if (list != NULL)
-		g_object_unref (list);
+	if (error_code != NULL)
+		g_object_unref (error_code);
+	if (array != NULL)
+		g_ptr_array_unref (array);
+	if (results != NULL)
+		g_object_unref (results);
+	g_free (data);
 	return ret;
 }
 
+/**
+ * gpk_pack_ready_cb:
+ **/
+static void
+gpk_pack_ready_cb (GObject *object, GAsyncResult *res, gpointer userdata)
+{
+	GtkWidget *widget;
+	PkServicePack *pack = PK_SERVICE_PACK (object);
+	GError *error = NULL;
+	gboolean ret;
+
+	/* get the results */
+	ret = pk_service_pack_generic_finish (pack, res, &error);
+	if (!ret) {
+		widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_pack"));
+		/* TRANSLATORS: we could not create the pack file, generic error */
+		gpk_error_dialog_modal (GTK_WINDOW (widget), _("Create error"), _("Cannot create service pack"), error->message);
+		g_error_free (error);
+	}
+
+	/* stop the action */
+	gpk_pack_widgets_activate (TRUE);
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "frame_progress"));
+	gtk_widget_hide (widget);
+	gpk_pack_set_percentage (100);
+
+	/* blank */
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "progressbar_percentage"));
+	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), "");
+}
+
+
+/**
+ * gpk_pack_progress_cb:
+ **/
+static void
+gpk_pack_progress_cb (PkProgress *progress, PkProgressType type, gpointer userdata)
+{
+	PkStatusEnum status;
+	gint percentage;
+	GtkProgressBar *progress_bar;
+	gchar *text;
+	gchar **split;
+	gchar *package_id;
+
+	g_object_get (progress,
+		      "status", &status,
+		      "percentage", &percentage,
+		      "package-id", &package_id,
+		      NULL);
+
+	if (type == PK_PROGRESS_TYPE_STATUS) {
+		egg_debug ("now %s", pk_status_enum_to_text (status));
+	} else if (type == PK_PROGRESS_TYPE_PERCENTAGE) {
+		gpk_pack_set_percentage (percentage);
+	} else if (type == PK_PROGRESS_TYPE_PACKAGE_ID) {
+		progress_bar = GTK_PROGRESS_BAR (gtk_builder_get_object (builder, "progressbar_percentage"));
+		split = pk_package_id_split (package_id);
+		/* TRANSLATORS: This is the package name that is being downloaded */
+		text = g_strdup_printf ("%s: %s-%s.%s",
+					_("Downloading"),
+					split[PK_PACKAGE_ID_NAME],
+					split[PK_PACKAGE_ID_VERSION],
+					split[PK_PACKAGE_ID_ARCH]);
+		gtk_progress_bar_set_text (progress_bar, text);
+		g_free (text);
+		g_strfreev (split);
+	}
+}
+
+/**
+ * gpk_pack_get_excludes_for_filename:
+ **/
+static gchar **
+gpk_pack_get_excludes_for_filename (const gchar *filename, GError **error)
+{
+	gboolean ret;
+	gchar *data = NULL;
+	gchar **split = NULL;
+	gchar **lines = NULL;
+	gchar **exclude_ids = NULL;
+	GPtrArray *array = NULL;
+	guint i;
+
+	/* get contents */
+	ret = g_file_get_contents (filename, &data, NULL, error);
+	if (!ret)
+		goto out;
+
+	/* split into lines */
+	array = g_ptr_array_new_with_free_func (g_free);
+	lines = g_strsplit (data, "\n", -1);
+	for (i=0; lines[i] != NULL; i++) {
+		/* split into sections */
+		split = g_strsplit (lines[i], "\t", -1);
+		if (g_strv_length (split) == 3)
+			g_ptr_array_add (array, g_strdup (split[1]));
+		g_strfreev (split);
+	}
+
+	/* convert to a string array */
+	exclude_ids = pk_ptr_array_to_strv (array);
+out:
+	if (array != NULL)
+		g_ptr_array_unref (array);
+	g_free (data);
+	g_strfreev (lines);
+	return exclude_ids;
+}
+
 /**
  * gpk_pack_button_create_cb:
  **/
@@ -371,12 +490,13 @@ gpk_pack_button_create_cb (GtkWidget *widget2, gpointer data)
 	gchar *exclude = NULL;
 	gchar **packages = NULL;
 	gchar **package_ids = NULL;
+	gchar **exclude_ids = NULL;
 	PkServicePack *pack;
-	PkPackageList *list = NULL;
 	GError *error = NULL;
 	gboolean ret;
 	gboolean use_default = FALSE;
 	GtkProgressBar *progress_bar;
+	PkError *error_code = NULL;
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "filechooserbutton_directory"));
 	directory = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER(widget));
@@ -389,19 +509,19 @@ gpk_pack_button_create_cb (GtkWidget *widget2, gpointer data)
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "frame_progress"));
 	gtk_widget_show (widget);
 
-	/* copy the system package list */
+	/* copy the system package array */
 	if (action == GPK_ACTION_ENUM_COPY) {
 		ret = gpk_pack_copy_package_lists (filename, &error);
 		if (!ret) {
 			widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_pack"));
-			/* TRANSLATORS: Could not create package list */
-			gpk_error_dialog_modal (GTK_WINDOW (widget), _("Create error"), _("Cannot copy system package list"), error->message);
+			/* TRANSLATORS: Could not create package array */
+			gpk_error_dialog_modal (GTK_WINDOW (widget), _("Create error"), _("Cannot copy system package array"), error->message);
 			g_error_free (error);
 		}
 		goto out;
 	}
 
-	/* get the exclude list, and fall back to the system copy */
+	/* get the exclude array, and fall back to the system copy */
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "filechooserbutton_exclude"));
 	exclude = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER(widget));
 	if (exclude == NULL) {
@@ -415,95 +535,82 @@ gpk_pack_button_create_cb (GtkWidget *widget2, gpointer data)
 		package = gtk_entry_get_text (GTK_ENTRY(widget));
 		if (egg_strzero (package)) {
 			widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_pack"));
-			/* TRANSLATORS: Could not create package list */
+			/* TRANSLATORS: Could not create package array */
 			gpk_error_dialog_modal (GTK_WINDOW (widget), _("Create error"), _("No package name selected"), NULL);
 			goto out;
 		}
-		/* split the package list with common delimiters */
+		/* split the package array with common delimiters */
 		packages = g_strsplit_set (package, ";, ", 0);
 		package_ids = gpk_pack_resolve_package_ids (packages, &error);
 		if (package_ids == NULL) {
 			widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_pack"));
-			/* TRANSLATORS: Could not create package list */
+			/* TRANSLATORS: Could not create package array */
 			gpk_error_dialog_modal (GTK_WINDOW (widget), _("Create error"), error->message, NULL);
 			g_error_free (error);
 			goto out;
 		}
 	}
 
-	/* if we're using the default list, and it doesn't exist, refresh and create it */
+	/* if we're using the default array, and it doesn't exist, refresh and create it */
 	if (use_default && !g_file_test (exclude, G_FILE_TEST_EXISTS)) {
-		/* reset client */
-		ret = pk_client_reset (client, &error);
-		if (!ret) {
-			widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_pack"));
-			/* TRANSLATORS: we could not reset internal state */
-			gpk_error_dialog_modal (GTK_WINDOW (widget), _("Refresh error"), _("Could not reset client"), error->message);
-			g_error_free (error);
-			goto out;
-		}
+		PkResults *results;
 
 		/* tell the user what we are doing */
 		progress_bar = GTK_PROGRESS_BAR (gtk_builder_get_object (builder, "progressbar_percentage"));
 		/* TRANSLATORS: progressbar text */
-		gtk_progress_bar_set_text (progress_bar, _("Refreshing system package list"));
+		gtk_progress_bar_set_text (progress_bar, _("Refreshing system package array"));
 
-		/* refresh package list */
-		ret = pk_client_refresh_cache (client, TRUE, &error);
-		if (!ret) {
+		/* refresh package array */
+		results = pk_client_refresh_cache (client, TRUE, NULL, NULL, NULL, &error);
+		if (results == NULL) {
 			widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_pack"));
 			/* TRANSLATORS: we could not reset internal state */
-			gpk_error_dialog_modal (GTK_WINDOW (widget), _("Refresh error"), _("Could not refresh package list"), error->message);
+			gpk_error_dialog_modal (GTK_WINDOW (widget), _("Refresh error"), _("Could not refresh package array"), error->message);
 			g_error_free (error);
 			goto out;
 		}
+
+		/* check error code */
+		error_code = pk_results_get_error_code (results);
+		if (error_code != NULL) {
+			egg_warning ("failed to refresh cache: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
+			goto out;
+		}
+
+		g_object_unref (results);
 	}
 
-	/* add the exclude list */
-	list = pk_package_list_new ();
-	ret = pk_obj_list_from_file (PK_OBJ_LIST(list), exclude);
-	if (!ret) {
+	/* add the exclude array */
+	exclude_ids = gpk_pack_get_excludes_for_filename (exclude, &error);
+	if (exclude_ids == NULL) {
 		widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_pack"));
-		/* TRANSLATORS: we could not read the file list for the destination computer */
-		gpk_error_dialog_modal (GTK_WINDOW (widget), _("Create error"), _("Cannot read destination package list"), NULL);
+		/* TRANSLATORS: we could not read the file array for the destination computer */
+		gpk_error_dialog_modal (GTK_WINDOW (widget), _("Create error"), _("Cannot read destination package array"), error->message);
+		g_error_free (error);
 		goto out;
 	}
 
 	/* create pack and set initial values */
 	pack = pk_service_pack_new ();
-	g_signal_connect (pack, "package", G_CALLBACK (gpk_pack_package_cb), pack);
-	g_signal_connect (pack, "percentage", G_CALLBACK (gpk_pack_percentage_cb), pack);
-	pk_service_pack_set_filename (pack, filename);
 	pk_service_pack_set_temp_directory (pack, NULL);
-	pk_service_pack_set_exclude_list (pack, list);
 
-	if (action == GPK_ACTION_ENUM_UPDATES)
-		ret = pk_service_pack_create_for_updates (pack, &error);
-	else if (action == GPK_ACTION_ENUM_PACKAGE)
-		ret = pk_service_pack_create_for_package_ids (pack, package_ids, &error);
-	if (!ret) {
-		widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_pack"));
-		/* TRANSLATORS: we could not create the pack file, generic error */
-		gpk_error_dialog_modal (GTK_WINDOW (widget), _("Create error"), _("Cannot create service pack"), error->message);
-		g_error_free (error);
+	if (action == GPK_ACTION_ENUM_UPDATES) {
+		pk_service_pack_create_for_updates_async (pack, filename, exclude_ids, NULL,
+							  (PkProgressCallback) gpk_pack_progress_cb, NULL,
+							  (GAsyncReadyCallback) gpk_pack_ready_cb, NULL);
+	} else if (action == GPK_ACTION_ENUM_PACKAGE) {
+		pk_service_pack_create_for_package_ids_async (pack, filename, package_ids, exclude_ids, NULL,
+							      (PkProgressCallback) gpk_pack_progress_cb, NULL,
+							      (GAsyncReadyCallback) gpk_pack_ready_cb, NULL);
 	}
 	g_object_unref (pack);
 
 out:
-	/* stop the action */
-	gpk_pack_widgets_activate (TRUE);
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "frame_progress"));
-	gtk_widget_hide (widget);
-	gpk_pack_set_percentage (100);
-
-	/* blank */
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "progressbar_percentage"));
-	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), "");
-
-	if (list != NULL)
-		g_object_unref (list);
+	if (error_code != NULL)
+		g_object_unref (error_code);
 	g_strfreev (packages);
 	g_strfreev (package_ids);
+	g_strfreev (exclude_ids);
 	g_free (directory);
 	g_free (exclude);
 }
@@ -572,36 +679,31 @@ gpk_pack_radio_copy_cb (GtkWidget *widget2, gpointer data)
 int
 main (int argc, char *argv[])
 {
-	gboolean verbose = FALSE;
 	GOptionContext *context;
 	GtkWidget *main_window;
 	GtkWidget *widget;
 	GtkFileFilter *filter;
 	GtkEntryCompletion *completion;
-	PkBitfield roles;
-	PkControl *control = NULL;
 	UniqueApp *unique_app;
 	gboolean ret;
-	GConfClient *gconf_client = NULL;
+	GSettings *settings = NULL;
 	gchar *option = NULL;
 	gchar *package = NULL;
-	gchar *with_list = NULL;
+	gchar *with_array = NULL;
 	gchar *output = NULL;
 	guint retval;
 	GError *error = NULL;
 
 	const GOptionEntry options[] = {
-		{ "verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose,
-		  _("Show extra debugging information"), NULL },
 		{ "option", 'o', 0, G_OPTION_ARG_STRING, &option,
 		  /* TRANSLATORS: the constants should not be translated */
-		  _("Set the option, allowable values are 'list', 'updates' and 'package'"), NULL },
+		  _("Set the option, allowable values are 'array', 'updates' and 'package'"), NULL },
 		{ "package", 'p', 0, G_OPTION_ARG_STRING, &package,
 		  /* TRANSLATORS: this refers to the GtkTextEntry in gpk-service-pack */
 		  _("Add the package name to the text entry box"), NULL },
-		{ "with-list", 'p', 0, G_OPTION_ARG_STRING, &with_list,
-		  /* TRANSLATORS: this is the destination computer package list */
-		  _("Set the remote package list filename"), NULL },
+		{ "with-array", 'p', 0, G_OPTION_ARG_STRING, &with_array,
+		  /* TRANSLATORS: this is the destination computer package array */
+		  _("Set the remote package array filename"), NULL },
 		{ "output", 'p', 0, G_OPTION_ARG_STRING, &output,
 		  /* TRANSLATORS: this is the file output directory */
 		  _("Set the default output directory"), NULL },
@@ -616,17 +718,21 @@ main (int argc, char *argv[])
 
 	if (! g_thread_supported ())
 		g_thread_init (NULL);
-	dbus_g_thread_init ();
 	g_type_init ();
 
 	context = g_option_context_new (NULL);
 	/* TRANSLATORS: program description, an application to create service packs */
-	g_option_context_set_summary(context, _("Service Pack Creator"));
+	g_option_context_set_summary (context, _("Service Pack Creator"));
 	g_option_context_add_main_entries (context, options, NULL);
-	g_option_context_parse (context, &argc, &argv, NULL);
+	g_option_context_add_group (context, egg_debug_get_option_group ());
+	g_option_context_add_group (context, gtk_get_option_group (TRUE));
+	ret = g_option_context_parse (context, &argc, &argv, &error);
+	if (!ret) {
+		g_error ("failed to parse %s", error->message);
+		g_error_free (error);
+	}
 	g_option_context_free (context);
 
-	egg_debug_init (verbose);
 	gtk_init (&argc, &argv);
 
 	/* are we already activated? */
@@ -639,19 +745,24 @@ main (int argc, char *argv[])
 	g_signal_connect (unique_app, "message-received",
 			  G_CALLBACK (gpk_pack_message_received_cb), NULL);
 
-	/* get actions */
-	control = pk_control_new ();
-	roles = pk_control_get_actions (control, NULL);
-
+	/* use a client to download packages */
 	client = pk_client_new ();
-	pk_client_set_use_buffer (client, TRUE, NULL);
-	pk_client_set_synchronous (client, TRUE, NULL);
-	g_signal_connect (client, "progress-changed", G_CALLBACK (gpk_pack_progress_changed_cb), NULL);
+	g_object_set (client,
+		      "background", FALSE,
+		      NULL);
+
+	/* get the properties of the daemon */
+	control = pk_control_new ();
+	ret = pk_control_get_properties (control, NULL, &error);
+	if (!ret) {
+		egg_error ("Failed to contact PackageKit: %s", error->message);
+		g_error_free (error);
+	}
 
 	/* get UI */
 	builder = gtk_builder_new ();
 	retval = gtk_builder_add_from_file (builder, GPK_DATA "/gpk-service-pack.ui", &error);
-	if (error != NULL) {
+	if (retval == 0) {
 		egg_warning ("failed to load ui: %s", error->message);
 		g_error_free (error);
 		goto out_build;
@@ -669,8 +780,8 @@ main (int argc, char *argv[])
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "filechooserbutton_exclude"));
 	filter = gtk_file_filter_new ();
 	/* TRANSLATORS: file search type, lists of packages */
-	gtk_file_filter_set_name (filter, _("Package list files"));
-	gtk_file_filter_add_pattern (filter, "*.package-list");
+	gtk_file_filter_set_name (filter, _("Package array files"));
+	gtk_file_filter_add_pattern (filter, "*.package-array");
 	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER(widget), filter);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "filechooserbutton_directory"));
@@ -698,8 +809,8 @@ main (int argc, char *argv[])
 	gtk_widget_hide (widget);
 
 	/* autocompletion can be turned off as it's slow */
-	gconf_client = gconf_client_get_default ();
-	ret = gconf_client_get_bool (gconf_client, GPK_CONF_AUTOCOMPLETE, NULL);
+	settings = g_settings_new (GPK_SETTINGS_SCHEMA);
+	ret = g_settings_get_boolean (settings, GPK_SETTINGS_AUTOCOMPLETE);
 	if (ret) {
 		/* create the completion object */
 		completion = gpk_package_entry_completion_new ();
@@ -710,7 +821,7 @@ main (int argc, char *argv[])
 
 	/* if command line arguments are set, then setup UI */
 	if (option != NULL) {
-		if (g_strcmp0 (option, "list") == 0) {
+		if (g_strcmp0 (option, "array") == 0) {
 			widget = GTK_WIDGET (gtk_builder_get_object (builder, "radiobutton_copy"));
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
 		} else if (g_strcmp0 (option, "updates") == 0) {
@@ -725,9 +836,9 @@ main (int argc, char *argv[])
 		widget = GTK_WIDGET (gtk_builder_get_object (builder, "entry_package"));
 		gtk_entry_set_text (GTK_ENTRY(widget), package);
 	}
-	if (with_list != NULL) {
+	if (with_array != NULL) {
 		widget = GTK_WIDGET (gtk_builder_get_object (builder, "filechooserbutton_exclude"));
-		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER(widget), with_list);
+		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER(widget), with_array);
 	}
 	if (output != NULL) {
 		widget = GTK_WIDGET (gtk_builder_get_object (builder, "filechooserbutton_directory"));
@@ -743,15 +854,15 @@ out_build:
 	g_object_unref (builder);
 out_unique:
 	g_object_unref (unique_app);
-	if (gconf_client != NULL)
-		g_object_unref (gconf_client);
+	if (settings != NULL)
+		g_object_unref (settings);
 	if (control != NULL)
 		g_object_unref (control);
 	if (client != NULL)
 		g_object_unref (client);
 	g_free (option);
 	g_free (package);
-	g_free (with_list);
+	g_free (with_array);
 	g_free (output);
 
 	return 0;
