@@ -32,6 +32,7 @@
 #include <locale.h>
 #include <libnotify/notify.h>
 #include <packagekit-glib2/packagekit.h>
+#include <unique/unique.h>
 
 #include "egg-debug.h"
 #include "egg-dbus-monitor.h"
@@ -55,7 +56,9 @@ main (int argc, char *argv[])
 	GpkFirmware *firmware = NULL;
 	GpkHardware *hardware = NULL;
 	GOptionContext *context;
+	UniqueApp *unique_app;
 	gboolean ret;
+	guint timer_id = 0;
 
 	const GOptionEntry options[] = {
 		{ "timed-exit", '\0', 0, G_OPTION_ARG_NONE, &timed_exit,
@@ -100,6 +103,14 @@ main (int argc, char *argv[])
 		return 1;
 	}
 
+	/* are we already activated? */
+	unique_app = unique_app_new ("org.freedesktop.PackageKit.UpdateIcon", NULL);
+	if (unique_app_is_running (unique_app)) {
+		egg_debug ("You have another instance running. This program will now close");
+		unique_app_send_message (unique_app, UNIQUE_ACTIVATE, NULL);
+		goto unique_out;
+	}
+
 	/* add application specific icons to search path */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
 					   GPK_DATA G_DIR_SEPARATOR_S "icons");
@@ -111,8 +122,12 @@ main (int argc, char *argv[])
 	hardware = gpk_hardware_new ();
 
 	/* Only timeout if we have specified iton the command line */
-	if (timed_exit)
-		g_timeout_add_seconds (120, (GSourceFunc) gtk_main_quit, NULL);
+	if (timed_exit) {
+		timer_id = g_timeout_add_seconds (120, (GSourceFunc) gtk_main_quit, NULL);
+#if GLIB_CHECK_VERSION(2,25,8)
+		g_source_set_name_by_id (timer_id, "[GpkUpdateIcon] timed exit");
+#endif
+	}
 
 	/* wait */
 	gtk_main ();
@@ -121,7 +136,8 @@ main (int argc, char *argv[])
 	g_object_unref (watch);
 	g_object_unref (firmware);
 	g_object_unref (hardware);
-
+unique_out:
+	g_object_unref (unique_app);
 	return 0;
 }
 
